@@ -1,10 +1,15 @@
-#Input assay data Menu for Data Analysis for Single dose
-options(warn=-1)
+###
+###  Input assay data Menu for Data Analysis for Single dose (don't analyze anything with this?  YJ)
+###
+
+
 NCAanalyze<-function(TotalSingledata, Dose,  Tau, TlastD, xaxis,yaxis, separateWindows=TRUE,
                      parallel=FALSE, MIX=FALSE, multiple=FALSE)
 {
-description_NCA()
 
+options(warn=-1)
+
+description_NCA()
 if (multiple) {
 with(Multiplentertitle(),{
 description_drug()
@@ -26,7 +31,7 @@ description_drug()
     SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
     SingleRdata1 <- na.omit(SingleRdata1)
 
-##SingleRdata1-->for select 3 points
+##SingleRdata1-->for select 2-6 points
 cat("\n\n")
    if(parallel){
    Test<-rbind(Singledata[[2]])
@@ -46,23 +51,24 @@ cat("\n\n")
 SingleRdata<-subset(SingleRdata0, time >=TlastD)
 SingleTdata<-subset(SingleTdata0, time >=TlastD)
 
-##SingleTdata1-->for select 3 points
+##SingleTdata1-->for select 2-6 points
 cat("\n\n")
 #'Total" for NCAplot
 Totalplot<- rbind(SingleRdata0,SingleTdata0)
 
    cat("\n")
-   file.menu <- c("Select 2-4 data points manually",            
-                  "Load previous selection (2-4 data points)",  
+   file.menu <- c("Select 2-6 data points manually",            
+                  "Load previous selection (.Rdata file)",  
                   "Use Adjusted R sq. (ARS) method",
                   "Use Akaike information criterion (AIC) method",                     
                   "Use the Two-Times-Tmax(TTT) method",
                   "Use TTT and ARS method",
                   "Use TTT and AIC method")                 
    cat("\n")               
-   pick <- menu(file.menu, title = "<< Lambda_z options >>")
+   pick <- menu(file.menu, title = "<< Estimation Methods for Lambda_z >>")
 
-   if (pick ==1){  
+   if (pick ==1){
+     description_pointselect()
      if(parallel){
       if(MIX){
       MultipleParaNCAselect.MIX(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis, Tau, TlastD,SingleRdata0,SingleTdata0) 
@@ -79,16 +85,23 @@ Totalplot<- rbind(SingleRdata0,SingleTdata0)
  else {
   if (pick == 2){
      description_load()
-     comdataname <-readline()
-     comdataname<-paste(comdataname,".RData",sep="")
-     load(comdataname)
+     ##  comdataname <-readline()
+     ##  comdataname<-paste(comdataname,".RData",sep="")
+     ##  load(comdataname)
+     comdata<-readRDS(file.choose())
      comdata<-edit(comdata)
      comdata<- na.omit(comdata)
      colnames(comdata)<-list("subj","time","conc","conc_data","drug")
      cat("\n\n")
      description_drug()
      show(comdata)
-     save(comdata,file=comdataname)
+##
+## no need to save it back again!  since this file has been created previously.-- YJ
+##
+##     cat("\n\n Enter the file name to be saved (no extension!):\n")
+##     comdataname <-readline()
+##     comdataname<-paste(comdataname,".RData",sep="")
+##     save(comdata,file=comdataname)
      cat("\n\n")
        
       Tcomdata<-split(comdata, list(comdata$drug))     
@@ -216,7 +229,7 @@ SingleRdata1<-Refdata[ do.call(order, Refdata) ,]
 SingleRdata1$conc[SingleRdata1$conc == 0] <- NA
 SingleRdata1 <- na.omit(SingleRdata1)
 
-##SingleRdata1-->for select 3 points
+##SingleRdata1-->for select 2-6 points
 cat("\n\n")
 if(parallel){
 Test<-rbind(Singledata[[2]])
@@ -233,23 +246,24 @@ SingleTdata1<-Testdata[ do.call(order, Testdata) ,]
 SingleTdata1$conc[SingleTdata1$conc == 0] <- NA
 SingleTdata1 <- na.omit(SingleTdata1)
 
-##SingleTdata1-->for select 3 points
+##SingleTdata1-->for select 2-6 points
 cat("\n\n")
 #'Total" for NCAplot
 Totalplot<- rbind(SingleRdata,SingleTdata)
 
    cat("\n")
-   file.menu <- c("Select 2-4 data points manually",            
-                  "Load previous selection (2-4 data points)",  
+   file.menu <- c("Select 2-6 data points manually",            
+                  "Load previous selection (2-6 data points)",  
                   "Use Adjusted R sq. (ARS) method",
                   "Use Akaike information criterion (AIC) method",                     
                   "Use the Two-Times-Tmax(TTT) method",
                   "Use TTT and ARS method",
                   "Use TTT and AIC method")                 
    cat("\n")               
-   pick <- menu(file.menu, title = "<< Lambda_z options >>")
+   pick <- menu(file.menu, title = "<< Estimation Methods for Lambda_z >>")
 
-   if (pick ==1){  
+   if (pick ==1){
+     description_pointselect()
      if(parallel){
       if(MIX){
       ParaNCAselect.MIX(Totalplot,SingleRdata1,SingleTdata1,Dose,SingleRdata,SingleTdata,xaxis, yaxis)
@@ -266,16 +280,23 @@ Totalplot<- rbind(SingleRdata,SingleTdata)
  else {
   if (pick == 2){
      description_load()
-     comdataname <-readline()
-     comdataname<-paste(comdataname,".RData",sep="")
-     load(comdataname)
+     ##  comdataname <-readline()
+     ##  comdataname<-paste(comdataname,".RData",sep="")
+     ##  load(comdataname)
+     comdata<-readRDS(file.choose())
      comdata<-edit(comdata)
      comdata<- na.omit(comdata)
      colnames(comdata)<-list("subj","time","conc","conc_data","drug")
      cat("\n\n")
      description_drug()
      show(comdata)
-     save(comdata,file=comdataname)
+##
+## no need to save it again!  since this file has been created previously.-- YJ
+##
+##     cat("\n\n Enter the file name to be saved (no extension!):\n")
+##     comdataname <-readline()
+##     comdataname<-paste(comdataname,".RData",sep="")
+##     save(comdata,file=comdataname)
      cat("\n\n")
        
       Tcomdata<-split(comdata, list(comdata$drug))     
