@@ -1,4 +1,4 @@
-description_drugcode<-function(replicated=FALSE){
+description_drugcode<-function(replicated=FALSE, multiple=FALSE){
 cat("\n")
 cat("****************************************************************************\n")
 cat("*<<Conc. - Time Plots >>                                                    \n")
@@ -11,6 +11,19 @@ cat("\n")
 
 cat("****************************************************************************\n")
 cat("<<Summary Result >>                                                         \n")
+if(multiple){
+cat(" AUC(tau)ss, Cmax_ss for the Reference and Test product                   \n")
+cat("----------------------------------------------------------------------------\n")
+cat(" TestAUC(tau)ss: the area under the predicted plasma concentration time   \n")
+cat("                   curve during a dosing interval (tau) at steady-state for \n")
+cat("                   for Test  product. (time = 0 to time of the last         \n")
+cat("                   measureable Cp)                                          \n")
+cat(" RefAUC(tau)ss: the area under the predicted plasma concentration time    \n")
+cat("                  curve during a dosing interval (tau) at steady-state for \n")
+cat("                  Reference product. (time = 0 to time of the last          \n")
+cat("                  measureable Cp)                                           \n")
+}
+else{
 cat(" AUC(0-t), AUC(0-inf), Cmax for the Reference and Test product              \n")
 cat("----------------------------------------------------------------------------\n")
 cat(" TestAUC0t: area under the plasma concentration time curve for Test         \n")
@@ -21,6 +34,7 @@ cat(" RefAUC0t: area under the plasma concentration time curve for Reference
 cat("           product. (time = 0 to time of the last measureable Cp)           \n")
 cat(" RefAUC0inf: area under the predicted plasma concentration time curve       \n")
 cat("             for Reference product. (time = 0 to infinity)                  \n")
+}
 cat("****************************************************************************\n")
 cat("\n")
 
@@ -30,7 +44,7 @@ cat("---------------------------------------------------------------------------
 cat(" Drug:                                                                      \n")
 cat("     1: Ref.                                                                \n")
 cat("     2: Test                                                                \n")
- if (replicated){
+ if (replicated || multiple){
  }
    else{
 cat(" Sequence:                                                                  \n")
